@@ -1,13 +1,10 @@
 package view
 
 import (
-	"errors"
 	"fmt"
-	"net"
-	"strconv"
 
-	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/dao"
+	"github.com/derailed/k9s/internal/port"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/k9s/internal/watch"
 	"github.com/gdamore/tcell/v2"
@@ -76,19 +73,11 @@ func (p *PortForwardExtender) fetchPodName(path string) (string, error) {
 // ----------------------------------------------------------------------------
 // Helpers...
 
-func tryListenPort(address, port string) error {
-	server, err := net.Listen("tcp", fmt.Sprintf("%s:%s", address, port))
-	if err != nil {
-		return err
-	}
-	return server.Close()
-}
-
 func runForward(v ResourceViewer, pf watch.Forwarder, f *portforward.PortForwarder) {
 	v.App().factory.AddForwarder(pf)
 
 	v.App().QueueUpdateDraw(func() {
-		v.App().Flash().Infof("PortForward activated %s:%s", pf.Path(), pf.Ports()[0])
+		v.App().Flash().Infof("PortForward activated %s", pf.ID())
 		DismissPortForwards(v, v.App().Content.Pages)
 	})
 
@@ -104,67 +93,77 @@ func runForward(v ResourceViewer, pf watch.Forwarder, f *portforward.PortForward
 	})
 }
 
-func startFwdCB(v ResourceViewer, path, co string, tt []client.PortTunnel) {
-	for _, t := range tt {
-		err := tryListenPort(t.Address, t.LocalPort)
-		if err != nil {
-			v.App().Flash().Err(err)
-			return
+func startFwdCB(v ResourceViewer, path string, pts port.PortTunnels) error {
+	if err := pts.CheckAvailable(); err != nil {
+		return err
+	}
+
+	for _, pt := range pts {
+		if _, ok := v.App().factory.ForwarderFor(dao.PortForwardID(path, pt.Container, pt.PortMap())); ok {
+			return fmt.Errorf("A port-forward is already active on pod %s", path)
 		}
+		pf := dao.NewPortForwarder(v.App().factory)
+		fwd, err := pf.Start(path, pt)
+		if err != nil {
+			return err
+		}
+		log.Debug().Msgf(">>> Starting port forward %q -- %#v", pf.ID(), pt)
+		go runForward(v, pf, fwd)
 	}
 
-	if _, ok := v.App().factory.ForwarderFor(dao.PortForwardID(path, co)); ok {
-		v.App().Flash().Err(errors.New("A port-forward is already active on this pod"))
-		return
-	}
-
-	pf := dao.NewPortForwarder(v.App().factory)
-	fwd, err := pf.Start(path, co, tt)
-	if err != nil {
-		v.App().Flash().Err(err)
-		return
-	}
-
-	log.Debug().Msgf(">>> Starting port forward %q %#v", path, tt)
-	go runForward(v, pf, fwd)
+	return nil
 }
 
 func showFwdDialog(v ResourceViewer, path string, cb PortForwardCB) error {
-	mm, err := fetchPodPorts(v.App().factory, path)
+	mm, anns, err := fetchPodPorts(v.App().factory, path)
 	if err != nil {
 		return err
 	}
-	ports := make([]string, 0, len(mm))
+	ports := make(port.ContainerPortSpecs, 0, len(mm))
 	for co, pp := range mm {
 		for _, p := range pp {
 			if p.Protocol != v1.ProtocolTCP {
 				continue
 			}
-			ports = append(ports, client.FQN(co, p.Name)+":"+strconv.Itoa(int(p.ContainerPort)))
+			ports = append(ports, port.NewPortSpec(co, p.Name, p.ContainerPort))
 		}
 	}
-	ShowPortForwards(v, path, ports, cb)
+	if spec, ok := anns[port.K9sAutoPortForwardsKey]; ok {
+		pfs, err := port.ParsePFs(spec)
+		if err != nil {
+			return err
+		}
+
+		pts, err := pfs.ToTunnels(v.App().Config.CurrentCluster().PortForwardAddress, ports, port.IsPortFree)
+		if err != nil {
+			return err
+		}
+
+		return startFwdCB(v, path, pts)
+	}
+
+	ShowPortForwards(v, path, ports, anns, cb)
 
 	return nil
 }
 
-func fetchPodPorts(f *watch.Factory, path string) (map[string][]v1.ContainerPort, error) {
+func fetchPodPorts(f *watch.Factory, path string) (map[string][]v1.ContainerPort, map[string]string, error) {
 	log.Debug().Msgf("Fetching ports on pod %q", path)
 	o, err := f.Get("v1/pods", path, true, labels.Everything())
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
 	var pod v1.Pod
 	err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &pod)
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
-	pp := make(map[string][]v1.ContainerPort)
+	pp := make(map[string][]v1.ContainerPort, len(pod.Spec.Containers))
 	for _, co := range pod.Spec.Containers {
 		pp[co.Name] = co.Ports
 	}
 
-	return pp, nil
+	return pp, pod.Annotations, nil
 }
