@@ -4,6 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"strings"
 
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/ui"
@@ -30,7 +31,8 @@ func (r *RestartExtender) bindKeys(aa ui.KeyActions) {
 		return
 	}
 	aa.Add(ui.KeyActions{
-		tcell.KeyCtrlT: ui.NewKeyAction("Restart", r.restartCmd, true),
+		// BOZO!!
+		ui.KeyR: ui.NewKeyAction("Restart", r.restartCmd, true),
 	})
 }
 
@@ -42,9 +44,9 @@ func (r *RestartExtender) restartCmd(evt *tcell.EventKey) *tcell.EventKey {
 
 	r.Stop()
 	defer r.Start()
-	msg := fmt.Sprintf("Restart deployment %s?", paths[0])
+	msg := fmt.Sprintf("Restart %s %s?", singularize(r.GVR().R()), paths[0])
 	if len(paths) > 1 {
-		msg = fmt.Sprintf("Restart %d deployments?", len(paths))
+		msg = fmt.Sprintf("Restart %d %s?", len(paths), r.GVR().R())
 	}
 	dialog.ShowConfirm(r.App().Styles.Dialog(), r.App().Content.Pages, "Confirm Restart", msg, func() {
 		ctx, cancel := context.WithTimeout(context.Background(), r.App().Conn().Config().CallTimeout())
@@ -53,7 +55,7 @@ func (r *RestartExtender) restartCmd(evt *tcell.EventKey) *tcell.EventKey {
 			if err := r.restartRollout(ctx, path); err != nil {
 				r.App().Flash().Err(err)
 			} else {
-				r.App().Flash().Infof("Rollout restart in progress for `%s...", path)
+				r.App().Flash().Infof("Restart in progress for `%s...", path)
 			}
 		}
 	}, func() {})
@@ -73,3 +75,13 @@ func (r *RestartExtender) restartRollout(ctx context.Context, path string) error
 
 	return s.Restart(ctx, path)
 }
+
+// Helpers...
+
+func singularize(s string) string {
+	if strings.LastIndex(s, "s") == len(s)-1 {
+		return s[:len(s)-1]
+	}
+
+	return s
+}
